@@ -110,7 +110,8 @@ class Query(ResourceBase):
         if self._env.schema() == "https":
             ws_schema = "wss"
         ws = create_connection(
-            f"{ws_schema}://{self._env.host()}:{self._env.port()}/ws/queries/{self.id()}"
+            f"{ws_schema}://{self._env.host()}:{self._env.port()}/ws/queries/{self.id()}",
+            header=[f"X-Api-Key: {self._env.api_key()}"],
         )
         for i in range(count):
             result = ws.recv()
@@ -123,8 +124,11 @@ class Query(ResourceBase):
             ws_schema = "ws"
             if self._env.schema() == "https":
                 ws_schema = "wss"
+
+            self._logger.info(f"using API key, {self._env.api_key()}")
             ws = create_connection(
-                f"{ws_schema}://{self._env.host()}:{self._env.port()}/ws/queries/{self.id()}"
+                f"{ws_schema}://{self._env.host()}:{self._env.port()}/ws/queries/{self.id()}",
+                header=[f"X-Api-Key: {self._env.api_key()}"],
             )
             start_time = time.time()
             try:
